import "../styles/globals.css";
import NProgress from "nprogress";
import "nprogress/nprogress.css";
import Router from "next/router";
import { useStore } from "react-redux";
import { PersistGate } from "redux-persist/integration/react";
import { wrapper } from "../redux/store";
import Layout from "../components/shared/layout/Layout";
import Script from "next/script";
import { useEffect} from "react";
import { useRouter } from "next/router";
import * as fbq from "../library/fpixel";
import Head from "next/head";

NProgress.configure({
  minimum: 0.7,
  easing: "ease",
  speed: 800,
  showSpinner: false,
});

Router.events.on("routeChangeStart", () => NProgress.start());
Router.events.on("routeChangeComplete", () => NProgress.done());
Router.events.on("routeChangeError", () => NProgress.done());

function MyApp({ Component, pageProps}) {
  const store = useStore((state) => state);
  const router = useRouter();
  const route = router.asPath;
  let newRoute = '';

  function removeLetter(str, letter) {
    const index = str.indexOf(letter);

    if (index !== -1) {
      return str.slice(0, index);
    }
    
    return str;
  }

  if (route.includes('?')) {
    newRoute ='https://miah.shop' + removeLetter(route, "?");
  } else {
    newRoute ='https://miah.shop'+route;
  }
  


  useEffect(() => {
    fbq.pageview();

    const handleRouteChange = () => {
      fbq.pageview();
    };

    router.events.on("routeChangeComplete", handleRouteChange);
    return () => {
      router.events.off("routeChangeComplete", handleRouteChange);
    };
  }, [router.events]);
  
  return (
    <>
      <Head>
        <meta
          name="viewport"
          content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no"
        />
        <meta name="google-site-verification" content="_O4ZoZH9uhxxk8A3w5sagMP1LLlBvjrfG6wW1mpN1Js" />
        <link rel="canonical" href ={newRoute} />
      </Head>
      <Script
        id="fb-pixel"
        strategy="afterInteractive"
        dangerouslySetInnerHTML={{
          __html: `
            !function(f,b,e,v,n,t,s)
            {if(f.fbq)return;n=f.fbq=function(){n.callMethod?
            n.callMethod.apply(n,arguments):n.queue.push(arguments)};
            if(!f._fbq)f._fbq=n;n.push=n;n.loaded=!0;n.version='2.0';
            n.queue=[];t=b.createElement(e);t.async=!0;
            t.src=v;s=b.getElementsByTagName(e)[0];
            s.parentNode.insertBefore(t,s)}(window, document,'script',
            'https://connect.facebook.net/en_US/fbevents.js');
            fbq('init', ${fbq.FB_PIXEL_ID});
            fbq('track', 'PageView');
            `,
        }}
      />
      <Script
        src="https://www.googletagmanager.com/gtag/js?id=G-J4TDD249F0"
        strategy="afterInteractive"
      />
      {/* <Script id="google-analytics" strategy="afterInteractive">
        {`
          window.dataLayer = window.dataLayer || [];
          function gtag(){dataLayer.push(arguments);}
          gtag('js', new Date());
        
          gtag('config', 'G-J4TDD249F0');
        `}
      </Script> */}

      {/* ============= no script part of tag manager is added in _document.js file ============== */}

      <Script id="google-tag-manager" strategy="afterInteractive">
        {`
          (function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start':
          new Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],
          j=d.createElement(s),dl=l!='dataLayer'?'&l='+l:'';j.async=true;j.src=
          'https://www.googletagmanager.com/gtm.js?id='+i+dl;f.parentNode.insertBefore(j,f);
          })(window,document,'script','dataLayer','GTM-N3ND7HV');
        `}
      </Script>

      {/* ============= no script part of tag manager is added in _document.js file ============== */}

      <Layout>
        <PersistGate persistor={store.__persistor}>
          {() => <Component {...pageProps}/>}
        </PersistGate>
      </Layout>
    </>
  );
}

export default wrapper.withRedux(MyApp);
